@@ -1,5 +1,5 @@
 /* WindowLab - an X11 window manager
- * Copyright (c) 2001-2006 Nick Gravgaard
+ * Copyright (c) 2001-2009 Nick Gravgaard
  * me at nickgravgaard.com
  * http://nickgravgaard.com/windowlab/
  *
@@ -52,6 +52,13 @@ void do_event_loop(void)
 #ifdef DEBUG
 		show_event(ev);
 #endif
+		/* check to see if menu rebuild has been requested */
+		if (do_menuitems)
+		{
+			free_menuitems();
+			get_menuitems();
+		}
+
 		switch (ev.type)
 		{
 			case KeyPress:
@@ -493,6 +500,7 @@ static void handle_property_change(XPropertyEvent *e)
 				if (c->name)
 				{
 					XFree(c->name);
+					c->name = NULL;
 				}
 				XFetchName(dsply, c->window, &c->name);
 				redraw(c);
