@@ -1,5 +1,5 @@
 /* WindowLab - an X11 window manager
- * Copyright (c) 2001-2006 Nick Gravgaard
+ * Copyright (c) 2001-2009 Nick Gravgaard
  * me at nickgravgaard.com
  * http://nickgravgaard.com/windowlab/
  *
@@ -59,7 +59,8 @@ void fork_exec(char *cmd)
 			}
 			else
 			{
-				*envshellname++;
+				/* move to the character after the slash */
+				envshellname++;
 			}
 			execlp(envshell, envshellname, "-c", cmd, NULL);
 			err("exec failed, cleaning up child");
@@ -73,15 +74,30 @@ void fork_exec(char *cmd)
 
 void sig_handler(int signal)
 {
+	pid_t pid;
+	int status;
+
 	switch (signal)
 	{
 		case SIGINT:
 		case SIGTERM:
-		case SIGHUP:
 			quit_nicely();
 			break;
+		case SIGHUP:
+			do_menuitems = 1;
+			break;
 		case SIGCHLD:
-			wait(NULL);
+			while ((pid = waitpid(-1, &status, WNOHANG)) != 0)
+			{
+				if ((pid == -1) && (errno != EINTR))
+				{
+					break;
+				}
+				else
+				{
+					continue;
+				}
+			}
 			break;
 	}
 }
