@@ -1,5 +1,5 @@
 /* WindowLab - an X11 window manager
- * Copyright (c) 2001-2006 Nick Gravgaard
+ * Copyright (c) 2001-2009 Nick Gravgaard
  * me at nickgravgaard.com
  * http://nickgravgaard.com/windowlab/
  *
@@ -21,8 +21,8 @@
 #ifndef WINDOWLAB_H
 #define WINDOWLAB_H
 
-#define VERSION "1.34"
-#define RELEASEDATE "2006-11-12"
+#define VERSION "1.39"
+#define RELEASEDATE "2009-12-27"
 
 #include <errno.h>
 #include <limits.h>
@@ -172,7 +172,8 @@ typedef struct PropMwmHints
 #define REMAP 1
 
 // stuff for the menu file
-#define MAX_MENUITEMS_SIZE (sizeof(MenuItem) * 64)
+#define MAX_MENUITEMS 24
+#define MAX_MENUITEMS_SIZE (sizeof(MenuItem) * MAX_MENUITEMS)
 #define STR_SIZE 128
 #define NO_MENU_LABEL "xterm"
 #define NO_MENU_COMMAND "xterm"
@@ -322,6 +323,7 @@ extern void redraw_taskbar(void);
 extern float get_button_width(void);
 
 // menufile.c
+extern int do_menuitems;
 extern MenuItem* menuitems;
 extern unsigned int num_menuitems;
 extern void get_menuitems(void);
